pub trait Duration:
Clone
+ Copy
+ AddAssign
+ PartialOrd {
// Required methods
fn zero() -> Self;
fn from_micros(micros: u64) -> Self;
fn is_zero(&self) -> bool;
fn div_duration_f64(self, rhs: Self) -> f64;
}Required Methods
Sourcefn from_micros(micros: u64) -> Self
fn from_micros(micros: u64) -> Self
Creates a new duration from the specified number of microseconds.
Sourcefn div_duration_f64(self, rhs: Self) -> f64
fn div_duration_f64(self, rhs: Self) -> f64
Divide this duration by another Duration and return f64.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".